# server_main.py

import threading
import asyncio
import socketserver

from config import HOST, HTTP_PORT, WS_PORT
from http_handler import RequestHandler
from ws_server import StartWsServer, MainEventLoop
from ws_server import broadcast_device_list  # might be used externally

class ThreadedHTTPServer(socketserver.ThreadingMixIn, socketserver.TCPServer):
    daemon_threads = True

def StartHttpServer():
    with ThreadedHTTPServer((HOST, HTTP_PORT), RequestHandler) as httpd:
        print(f"[HTTP] Listening on {HOST}:{HTTP_PORT} (ThreadedMixIn)")
        httpd.serve_forever()

def main():
    global MainEventLoop
    MainEventLoop = asyncio.get_event_loop()

    # 1) Start HTTP in background thread
    http_thread = threading.Thread(target=StartHttpServer, name="HttpServerThread", daemon=True)
    http_thread.start()

    # 2) Start WebSocket in the main thread
    MainEventLoop.run_until_complete(StartWsServer(HOST, WS_PORT))

if __name__ == "__main__":
    main()
