# device_manager.py

import time
import threading

DevicesLock = threading.Lock()
Devices = {}  
# Structure: { deviceName: {"ip": "X.X.X.X", "lastPing": <timestamp>} }

def register_device(name, ip):
    """
    Register or update the device with the given name & IP. Thread-safe.
    """
    with DevicesLock:
        Devices[name] = {
            "ip": ip,
            "lastPing": time.time()
        }

def update_ping(name, ip):
    """
    Update lastPing for device. If not present, register it automatically.
    """
    with DevicesLock:
        if name not in Devices:
            Devices[name] = {"ip": ip, "lastPing": time.time()}
        else:
            Devices[name]["ip"] = ip
            Devices[name]["lastPing"] = time.time()

def device_exists(name):
    with DevicesLock:
        return (name in Devices)

def get_device_ip(name):
    with DevicesLock:
        if name in Devices:
            return Devices[name]["ip"]
        return None

def list_device_names():
    with DevicesLock:
        return list(Devices.keys())
