# ws_server.py

import asyncio
from websockets import serve
from device_manager import list_device_names

WebSocketSessions = set()
MainEventLoop = None  # We'll assign this from server_main.py

async def WsHandler(websocket, path):
    WebSocketSessions.add(websocket)
    try:
        # Send current device list
        names = list_device_names()
        await websocket.send(",".join(names))

        async for _msg in websocket:
            # In this demo, we ignore inbound messages
            pass

    except:
        pass
    finally:
        if websocket in WebSocketSessions:
            WebSocketSessions.remove(websocket)

async def StartWsServer(host, port):
    print(f"[WebSocket] Listening on {host}:{port}")
    async with serve(WsHandler, host, port):
        await asyncio.Future()  # run forever

def broadcast_device_list():
    """
    Called by the HTTP thread to notify WebSocket clients of any device updates.
    """
    if not MainEventLoop or not WebSocketSessions:
        return
    names = list_device_names()
    msg = ",".join(names)
    asyncio.run_coroutine_threadsafe(_broadcast_message(msg), MainEventLoop)

async def _broadcast_message(message):
    for ws in list(WebSocketSessions):
        try:
            await ws.send(message)
        except:
            pass
