import network
import time

#Modify to match your network
WIFI_SSID = "YourSSID"
WIFI_PASSWORD = "YourSSIDPassword"
PREFERRED_IPS = ["192.168.1.30", "192.168.1.230"]
NETMASK = "255.255.255.0"
GATEWAY = "192.168.1.1"
DNS = "192.168.1.1"

def ConnectWiFi(ssid=None, password=None, preferred_ips=None, netmask=None, gateway=None, dns=None):
    """
    Attempts to connect to Wi-Fi using a list of preferred IP addresses.
    If all fail, tries DHCP. Returns True on success, False on failure.
    """
    if ssid is None:
        ssid = WIFI_SSID
    if password is None:
        password = WIFI_PASSWORD
    if preferred_ips is None:
        preferred_ips = PREFERRED_IPS
    if netmask is None:
        netmask = NETMASK
    if gateway is None:
        gateway = GATEWAY
    if dns is None:
        dns = DNS

    import network
    try:
        wlan = network.WLAN(network.STA_IF)
        wlan.active(True)
        for ip in preferred_ips:
            if not wlan.isconnected():
                print("[WiFi] Trying to connect with IP", ip)
                wlan.ifconfig((ip, netmask, gateway, dns))
                wlan.connect(ssid, password)
                start_time = time.ticks_ms()
                while not wlan.isconnected():
                    if time.ticks_diff(time.ticks_ms(), start_time) > 10000:
                        print("[WiFi] Failed to connect with preferred IP", ip)
                        break
                    time.sleep(1)
                current_ip = wlan.ifconfig()[0]
                if current_ip == ip:
                    print("[WiFi] Successfully connected with preferred IP:", ip)
                    break
                else:
                    print("[WiFi] Connected, but not with preferred IP", ip, "Retrying next IP.")
                    wlan.disconnect()
                    time.sleep(1)
            else:
                print("[WiFi] Already connected. Checking IP...")
                current_ip = wlan.ifconfig()[0]
                if current_ip in preferred_ips:
                    print("[WiFi] Using preferred IP:", current_ip)
                    break
                else:
                    print("[WiFi] Connected, but not with a preferred IP. Disconnecting...")
                    wlan.disconnect()
                    time.sleep(1)
        else:
            if wlan.isconnected():
                print("[WiFi] Connected via DHCP IP:", wlan.ifconfig()[0])
                return True
            else:
                print("[WiFi] Failed to connect to Wi-Fi with preferred IPs.")
                return False

        return True
    except Exception as e:
        print("[WiFi] Exception in ConnectWiFi:", e)
        return False
